@@ -30,7 +30,7 @@ def read_yaml_to_dict(yaml_path: str) -> dict:
 
 class google_handler:
     """
-    Before starting - know i made an assumption that a file\dir name is unique.
+    Before starting - know i made an assumption that a file/dir name is unique.
     From some reason, google allow same file or dir name in the same dir. e.g. 'root/a.txt' twice
     If you have duplicates - this will be notified upon creation of this class
 
@@ -115,16 +115,17 @@ class google_handler:
                 else:  # no cred file found
                     raise e
 
-            duplicates_list = []
-            for full_path, file_d in self.all_files_dict.items():
-                if file_d['id'] == 'Duplicated':
-                    duplicates_list.append(full_path)
+            if self.all_files_dict is not None:
+                duplicates_list = []
+                for full_path, file_d in self.all_files_dict.items():
+                    if file_d['id'] == 'Duplicated':
+                        duplicates_list.append(full_path)
 
-            if len(duplicates_list) > 0:
-                mt.exception_error('Found duplicated files or dirs:', real_exception=False, tabs=tabs)
-                for dup in duplicates_list:
-                    print(mt.add_color('\t{}{}'.format(tabs * '\t', dup), ops='red'))
-                exit(-1)
+                if len(duplicates_list) > 0:
+                    mt.exception_error('Found duplicated files or dirs:', real_exception=False, tabs=tabs)
+                    for dup in duplicates_list:
+                        print(mt.add_color('\t{}{}'.format(tabs * '\t', dup), ops='red'))
+                    exit(-1)
 
             self.tabs = tabs
             self.dir_color = dir_color
