@@ -454,7 +454,7 @@ def version() -> str:
     :return:
     """
     # v = pkg_resources.require("wizzi_utils")[0].version
-    v = '7.0.17'
+    v = '7.1.21'
     return v
 
 
@@ -550,6 +550,18 @@ def get_wizzi_utils_root() -> str:
     return project_root
 
 
+def get_py_version() -> str:
+    """
+    on linux there is \n and then gcc
+    e.g.
+    3.7.3 (default, Jan 22 2021, 20:04:44)
+    [GCC 8.3.0]
+    :return:
+    """
+    py_ver = sys.version.replace('\n', '')
+    return py_ver
+
+
 def main_wrapper(
         main_function: Callable,
         seed: int = -1,
@@ -590,7 +602,7 @@ def main_wrapper(
 
     print('main_wrapper:')
     print('* Run started at {}'.format(get_time_stamp(format_s='%d-%m-%Y %H:%M:%S')))
-    print('* Python Version {}'.format(sys.version))
+    print('* Python Version {}'.format(get_py_version()))
     print('* Operating System {}'.format(get_system_info()))
     print('* Interpreter: {}'.format(sys.executable))
     print('* wizzi_utils Version {}'.format(version()))
@@ -600,7 +612,7 @@ def main_wrapper(
         print('* Computer Mac: {}'.format(get_mac_address_uuid()))
     except (ImportError, ModuleNotFoundError, NameError, AttributeError) as err:
         print(add_color('* {}'.format(err), 'r'))
-   
+
     print('* CPU Info: {}'.format(cpu_info(one_liner=True, tabs=0)))
     print('* Physical Memory: {}'.format(hard_disc(one_liner=True, tabs=0)))
     print('* RAM: {}'.format(ram_size(one_liner=True, tabs=0)))
@@ -1917,12 +1929,8 @@ def cpu_info(one_liner: bool = False, tabs: int = 1):
 
 def wizzi_utils_requirements():
     print('A snapshot of my environment packages:')
-    req_file = '../wizzi_utils_requirements.txt'
-    file = open(req_file, 'r')
-    lines = file.readlines()
-    file.close()
-    for i, line in enumerate(lines):
-        print("{}) {}".format(i + 1, line.rstrip()))
+    req_file = '../resources/wizzi_utils_requirements.txt'
+    _ = read_file_lines(fp=req_file, ack=True, tabs=0)
     return
 
 
@@ -2076,16 +2084,39 @@ class FPS:
     see classFPS_test()
     """
 
-    def __init__(self, last_k: int = 100, summary_title: str = None) -> None:
+    def __init__(self, last_k: int = 100, summary_title: str = None, cache_size: int = 10000) -> None:
         """
         :param last_k: average of the last k measures
         :param summary_title:
+        :param cache_size: >=last_k
+        in case your program runs on an infinite loop, limit the size of the times_elapsed list.
+        |times_elapsed| <= cache_size + last_k
+        e.g. let cache_size=1000 and last_k=100
+        till iter 1100 times_elapsed fills
+        on iter 1100:
+            pop first 1000 and add only the sum to run_time_sum
+            times_elapsed = times_elapsed last 100 indices
+        on iter 2100: |times_elapsed| = 1100
+            pop first 1000 and add only the sum to run_time_sum
+            times_elapsed = times_elapsed last 100 indices
+        on iter 2350 run end:
+        |times_elapsed| = 350
+        run_time_sum is a float sum of first 2000 iters
+        total time run_time_sum + sum(times_elapsed)
+        total time avg = total time / iter_num
+        last_k avg = sum(times_elapsed[-last_k:]) / last_k
         """
         self.timer_begin = None
         self.timer_end = None
         self.times_elapsed = []
+        self.cache_size = cache_size
+        if cache_size < last_k:
+            self.cache_size = last_k
+        self.run_time_sum = 0.0
+        self.iter_num = 0
         self.summary_title = summary_title
         self.last_k = last_k
+        self.avg_epsilon = 0.0001
         return
 
     def __del__(self) -> None:
@@ -2099,7 +2130,7 @@ class FPS:
             string = tabs * '\t'
             if with_title:
                 string += '{}:'.format(self.summary_title)
-            string += 'Iter {} Started:'.format(len(self.times_elapsed) + 1)
+            string += 'Iter {} Started:'.format(self.iter_num + 1)
             print(string)
         self.timer_begin = get_timer()
         self.timer_end = None
@@ -2111,7 +2142,14 @@ class FPS:
         else:
             self.timer_end = get_timer()
             time_elapsed = self.timer_end - self.timer_begin
+            self.iter_num += 1
             self.times_elapsed.append(time_elapsed)
+            if len(self.times_elapsed) >= self.last_k + self.cache_size:
+                # if |self.times_elapsed| > self.last_k + self.cache_size:
+                # take the first 'self.cache_size' and save the sum.
+                # new |self.times_elapsed|=self.last_k
+                self.run_time_sum += np.sum(self.times_elapsed[:self.cache_size])
+                self.times_elapsed = self.times_elapsed[-self.last_k:]
 
             if ack_progress:
                 self.so_far(tabs, with_title)
@@ -2123,7 +2161,7 @@ class FPS:
         fps = -1.0
         if len(self.times_elapsed) > 0:
             avg_times = np.mean(self.times_elapsed[-self.last_k:])
-            if avg_times > 0.0001:
+            if avg_times > self.avg_epsilon:
                 fps = 1 / avg_times
         return fps
 
@@ -2132,7 +2170,7 @@ class FPS:
             string = tabs * '\t'
             if with_title:
                 string += '{}:'.format(self.summary_title)
-            string += 'Iter {} Done: '.format(len(self.times_elapsed))
+            string += 'Iter {} Done: '.format(self.iter_num)
 
             # rt_str = self.convert()
             rt_str = '{:.3f}s'.format(self.times_elapsed[-1])
@@ -2143,7 +2181,7 @@ class FPS:
                 string += 'totalTime={:.3f}s, '.format(np.sum(self.times_elapsed[-self.last_k:]))
                 string += 'avgTime={:.3f}s, '.format(avg_times)
 
-            if avg_times > 0.0001:
+            if avg_times > self.avg_epsilon:
                 fps = '{:.2f} FPS'.format(1 / avg_times)
             else:
                 fps = 'FPS very high'.format(tabs * '\t')
@@ -2151,10 +2189,6 @@ class FPS:
             print(string)
         return
 
-    def clear(self) -> None:
-        self.times_elapsed = []
-        return
-
     def finalize(self, tabs: int = 1) -> None:
         tabs_s = tabs * '\t'
         if len(self.times_elapsed) > 0:
@@ -2163,20 +2197,20 @@ class FPS:
             if self.summary_title is not None:
                 title += 'of {}'.format(self.summary_title)
             # add rounds to title
-            title += '({} iters)'.format(len(self.times_elapsed))
+            title += '({} iters)'.format(self.iter_num)
             print('{}{}'.format(tabs_s, add_color(title, ops='underlined')))
 
             # total time
-            total = '{}\tTotal   Run Time = {:.3f}s'.format(tabs_s, np.sum(self.times_elapsed))
+            t_time = np.sum(self.times_elapsed) + self.run_time_sum
+            total = '{}\tTotal   Run Time = {:.3f}s'.format(tabs_s, t_time)
             print(total)
 
             # average time
-            avg_times = np.mean(self.times_elapsed)
-            std_times = np.std(self.times_elapsed)
-            avg_str = '{}\tAverage Run Time(all t) = {:.3f}s (std = {:.3f})'.format(tabs_s, avg_times, std_times)
+            avg_times = t_time / self.iter_num
+            avg_str = '{}\tAverage Run Time(all t) = {:.3f}s'.format(tabs_s, avg_times)
 
             # FPS
-            if avg_times > 0.0001:
+            if avg_times > self.avg_epsilon:
                 fps = ' {:.2f} FPS'.format(1 / avg_times)
             else:
                 fps = 'FPS very high'
@@ -2187,11 +2221,10 @@ class FPS:
             # average time last k
             avg_times_k = np.mean(self.times_elapsed[-self.last_k:])
             std_times_k = np.std(self.times_elapsed[-self.last_k:])
-            avg_str_k = '{}\tAverage Run Time(last {}) = {:.3f}s (std = {:.3f})'.format(tabs_s, self.last_k,
-                                                                                        avg_times_k,
-                                                                                        std_times_k)
+            avg_str_k_raw = '{}\tAverage Run Time(last {}) = {:.3f}s (std = {:.3f})'
+            avg_str_k = avg_str_k_raw.format(tabs_s, self.last_k, avg_times_k, std_times_k)
             # FPS last k
-            if avg_times > 0.0001:
+            if avg_times > self.avg_epsilon:
                 fps_k = ' {:.2f} FPS'.format(1 / avg_times_k)
             else:
                 fps_k = 'FPS very high'
@@ -2288,13 +2321,17 @@ def generate_requirements_file(fp_out: str, ack: bool = True) -> None:
         # main_wrapper()
         out.write('# main_wrapper:\n')
         out.write('# * Run started at {}\n'.format(get_time_stamp(format_s='%d-%m-%Y %H:%M:%S')))
-        py_ver = sys.version.replace('\n', '')  # on linux there is \n and then gcc
-        out.write('# * Python Version {}\n'.format(py_ver))
+        out.write('# * Python Version {}\n'.format(get_py_version()))
         out.write('# * Operating System {}\n'.format(remove_colors(get_system_info())))
         out.write('# * Interpreter: {}\n'.format(sys.executable))
         out.write('# * wizzi_utils Version {}\n'.format(version()))
         out.write('# * Working Dir: {}\n'.format(os.getcwd()))
-        out.write('# * Computer Mac: {}\n'.format(remove_colors(get_mac_address())))
+        try:
+            from wizzi_utils.socket.socket_tools import get_mac_address_uuid
+            out.write('# * Computer Mac: {}\n'.format(remove_colors(get_mac_address_uuid())))
+        except (ImportError, ModuleNotFoundError, NameError, AttributeError) as err:
+            print(add_color('* {}'.format(err), 'r'))
+
         out.write('# * CPU Info: {}\n'.format(remove_colors(cpu_info(one_liner=True, tabs=0))))
         out.write('# * Physical Memory: {}\n'.format(remove_colors(hard_disc(one_liner=True, tabs=0))))
         out.write('# * RAM: {}\n'.format(remove_colors(ram_size(one_liner=True, tabs=0))))
@@ -2506,3 +2543,98 @@ def has_admin(ack: bool = True) -> (str, bool):
     if ack:
         print('Username {} is admin ? {}'.format(user_name, is_admin))
     return user_name, is_admin
+
+
+def read_file_lines(
+        fp: str,
+        strip: bool = True,  # remove trailing white spaces from both sides
+        multi_spaces: bool = True,  # change multi spaces to 1 space
+        clear_n: bool = True,  # remove \n (new line)
+        clear_r: bool = True,  # remove \r (cartridge)
+        clear_t: bool = True,  # remove \t (tabs)
+        ack: bool = False,
+        tabs: int = 1
+) -> list:
+    lines = []
+    if os.path.exists(fp):
+        with open(fp) as file:
+            lines_raw = file.readlines()
+            for line in lines_raw:
+                if strip:
+                    line = line.strip()
+                if clear_n:
+                    line = line.replace('\n', '')
+                if clear_r:
+                    line = line.replace('\r', '')
+                if clear_t:
+                    line = line.replace('\t', '')
+                if multi_spaces:
+                    line = ' '.join(line.split())
+                lines.append(line)
+            if ack:
+                for i, line in enumerate(lines):
+                    print('{}line {:3}: {}'.format(tabs * '\t', i, line))
+                    # print('\t line {}: {}'.format(i, repr(line)))
+    else:
+        exception_error(e='File {} not found'.format(os.path.abspath(fp)))
+    return lines
+
+
+def get_path_file_system_info(path: str, ack: bool = False) -> (str, str, str, str):
+    """
+    :param path: of file or dir
+    :param ack:
+    :return: mount name, device name, file system type
+    e.g. let my_py.py script be somewhere on D: drive
+         find_device_name_of_path('./my_py.py)
+         dir D:/...somewhere.../my_py.py
+            mount=D:
+            device_name=D:
+            file system type=NTFS
+            free space=714.2 GB
+    """
+    cur_mount_name, device_name, fs_type, free_space = 'N/A', 'N/A', 'N/A', 'N/A'
+    if not os.path.exists(path):
+        exception_error(e='File {} not found'.format(os.path.abspath(path)))
+        return cur_mount_name, device_name, fs_type, free_space
+
+    cur_mount_name = os.path.abspath(path)
+    while not os.path.ismount(cur_mount_name):
+        cur_mount_name = os.path.dirname(cur_mount_name)
+
+    for p in psutil.disk_partitions():
+        if p.mountpoint == cur_mount_name:
+            cur_mount_name = cur_mount_name.replace('\\', '')  # strip \ chars
+            device_name = p.device.replace('\\', '')  # strip \ chars
+            fs_type = p.fstype  # empty string is valid
+            break
+    _, free_space = size_remain(partition=device_name, ack=False)
+    if ack:
+        pref = 'file' if os.path.isfile(path) else 'dir'
+        print(f'{pref} {os.path.abspath(path)}:')
+        print(f'\tmount={cur_mount_name}')
+        print(f'\tdevice_name={device_name}')
+        print(f'\tfile system type={fs_type}')
+        print(f'\tfree space={free_space}')
+    return cur_mount_name, device_name, fs_type, free_space
+
+
+def add_resource_folder_to_path(resources_dir: str) -> None:
+    """
+    :param resources_dir: full path of folder that the py file will "see"
+    :return:
+    e.g. when i wanted to record using x264 coded on Windows, there was a dll missing.
+    the solution i found was to download the dll and place it next to the py file so it can "see" it.
+    that worked, but now there is a dll file "stuck" next to my py file. this fuction will allow you to place the dll
+    (and all other resources files) in a folder and add it to the PATH variable
+    see wu.cvt.test.video_creator_size_test() for an example
+    """
+    if not os.path.exists(resources_dir):
+        print('not found {}'.format(os.path.abspath(resources_dir)))
+    elif not os.path.isdir(resources_dir):
+        print('not a directory {}'.format(os.path.abspath(resources_dir)))
+    else:
+        path_env = get_env_variable(key='PATH')
+        path_env = '{};{}'.format(path_env, os.path.abspath(resources_dir))  # add resources_dir to PATH env variable
+        set_env_variable(key='PATH', val=path_env)
+    return
