@@ -544,12 +544,8 @@ def logger_test():
     mt.log_print(line='line 3', tabs=3)
     mt.close_logger()
 
-    print('\treading from {}'.format(path))
-    file1 = open(path, 'r')
-    lines = file1.readlines()
-    file1.close()
-    for i, line in enumerate(lines):
-        print("\t\tLine{}: {}".format(i + 1, line.rstrip()))
+    print('reading from {}'.format(path))
+    mt.read_file_lines(fp=path, ack=True)
     mt.delete_dir_with_files(TEMP_FOLDER1)
     return
 
@@ -837,18 +833,36 @@ def compress_and_extract_test():
 
 def classFPS_test():
     mt.get_function_name_and_line(ack=True, tabs=0)
-    fps = mt.FPS(last_k=2, summary_title='classFPS_test')
+    # fps = mt.FPS(last_k=50, cache_size=100, summary_title='classFPS_test')
+    # tabs = 1
+    # print('{}test empty get_fps() = {:.4f}'.format(tabs * '\t', fps.get_fps()))
+    # for t in range(500):
+    #     ack = (t + 1) % 40 == 0
+    #     fps.start(ack_progress=ack, tabs=tabs)
+    #     # do_work of round t
+    #     mt.sleep(seconds=0.03)
+    #     if t == 0:
+    #         mt.sleep(seconds=1)
+    #     fps.update(ack_progress=ack, tabs=tabs + 1)
+    #     if ack:
+    #         print('{}\tget_fps() = {:.4f}'.format(tabs * '\t', fps.get_fps()))
+    # fps.finalize(tabs)
+
+    fps = mt.FPS(last_k=2, cache_size=2, summary_title='classFPS_test')
     tabs = 1
     print('{}test empty get_fps() = {:.4f}'.format(tabs * '\t', fps.get_fps()))
-    for t in range(3):
-        fps.start(ack_progress=True, tabs=tabs)
+    for t in range(10):
+        ack = (t + 1) % 1 == 0
+        fps.start(ack_progress=ack, tabs=tabs)
         # do_work of round t
         mt.sleep(seconds=0.03)
         if t == 0:
             mt.sleep(seconds=1)
-        fps.update(ack_progress=True, tabs=tabs + 1)
-        print('{}\tget_fps() = {:.4f}'.format(tabs * '\t', fps.get_fps()))
+        fps.update(ack_progress=ack, tabs=tabs + 1)
+        if ack:
+            print('{}\tget_fps() = {:.4f}'.format(tabs * '\t', fps.get_fps()))
     fps.finalize(tabs)
+
     return
 
 
@@ -892,13 +906,14 @@ def generate_requirements_file_test():
     mt.get_function_name_and_line(ack=True, tabs=0)
     fp = '{}/requirements.txt'.format(PLAY_GROUND)
     mt.generate_requirements_file(fp_out=fp)
-    file1 = open(fp, 'r')
-    lines = file1.readlines()
-    file1.close()
-    print('\nfile content:')
-    for i, line in enumerate(lines):
-        print("\t{}".format(line.rstrip()))
+    # file1 = open(fp, 'r')
+    # lines = file1.readlines()
+    # file1.close()
+    # print('\nfile content:')
+    # for i, line in enumerate(lines):
+    #     print("\t{}".format(line.rstrip()))
     # mt.delete_file(fp)
+    _ = mt.read_file_lines(fp=fp, ack=True, tabs=0)
     return
 
 
@@ -1000,6 +1015,34 @@ def has_admin_test():
     return
 
 
+def read_file_lines_test():
+    mt.get_function_name_and_line(ack=True, tabs=0)
+
+    src_path = '{}/{}'.format(TEMP_FOLDER1, DEMO_FILE)
+    create_demo_file(src_path)  # create a file
+
+    # add junk
+    f = open(src_path, "w")
+    f.write("  first     line \n")
+    f.write("           2nd     line               \n")
+    f.close()
+
+    mt.read_file_lines(fp=src_path, ack=True)
+    return
+
+
+def get_path_file_system_info_test():
+    _, _, _, _ = mt.get_path_file_system_info(path=PLAY_GROUND, ack=True)
+    if mt.is_windows():
+        if os.path.exists('C:\\Windows\\System32'):
+            mt.get_path_file_system_info(path='C:\\Windows\\System32', ack=True)
+    if mt.is_linux():
+        mt.get_path_file_system_info(path='/home', ack=True)
+
+    _, _, _, _ = mt.get_path_file_system_info(path='./fake_file.py', ack=True)
+    return
+
+
 def test_all():
     print('{}{}:'.format('-' * 5, mt.get_base_file_and_function_name(depth=1)))
     try_say_welcome()
@@ -1007,7 +1050,6 @@ def test_all():
     timer_action_test()
     get_time_stamp_test()
     get_pc_name_test()
-    get_mac_address_test()
     get_cuda_version_test()
     get_env_variables_test()
     set_env_variable_test()
@@ -1074,5 +1116,7 @@ def test_all():
     convert_size_test()
     get_emoji_test()
     has_admin_test()
+    read_file_lines_test()
+    get_path_file_system_info_test()
     print('{}'.format('-' * 20))
     return
