@@ -811,9 +811,21 @@ class VideoCreator:
         mp4v -> file.mp4
         MJPG or XVID-> file.avi
         H264 or X264 -> file.mkv
-        # if u see error like:
-        Failed to load OpenH264 library: openh264-1.8.0-win64.dll
-        look for that file online, download and place next to the py file
+        # if u see error like when you use H264 or X264 on windows:
+        "Failed to load OpenH264 library: openh264-1.8.0-win64.dll"
+        look for the correct file by the name online (could be python version dependant)
+        and add this code:
+        if wu.is_windows():
+            # dll for H264 and X264 codecs for python 3.8
+            mkv_dll_path = r'../../AuxFiles' # set this to the dir of the dll
+            if not os.path.exists(mkv_dll_path):
+                print('not found {}'.format(os.path.abspath(mkv_dll_path)))
+                exit(-9)
+            path_env = wu.get_env_variable(key='PATH')
+            path_env = '{};{}'.format(path_env, os.path.abspath(mkv_dll_path))  # add mkv_dll_path
+            wu.set_env_variable(key='PATH', val=path_env)
+            # wu.get_env_variable(key='PATH', ack=True)
+        you can also add the folder to env vars of windows and also via pycharm configuration
         """
 
         self.out_full_path = out_full_path
