@@ -580,6 +580,7 @@ def video_creator_mp4_test():
 
 def video_creator_size_test():
     wu.get_function_name(ack=True, tabs=0)
+    wu.add_resource_folder_to_path(resources_dir='../resources')
     # now open video file
     vid_name = mtt.DOG1
     video_path = get_vid_from_web(name=vid_name)
@@ -635,6 +636,7 @@ def video_creator_size_test():
     print('codes to file size summary:')
     for codec, file_size in zip(codecs, sizes):
         print('\t{}: {}'.format(codec, file_size))
+    wu.delete_dir_with_files(out_dir)
     return
 
 
@@ -1029,6 +1031,7 @@ def align_images_test():
     aligned_images = cvt.align_images(imgs=[cv_img1, cv_img2, cv_img3, cv_img4], pad_colors=['g', 'w', 'purple'])
     cvt.display_open_cv_images(imgs=aligned_images, grid=(2, 2), resize=0.3, loc='tl', ms=BLOCK_MS_NORMAL,
                                title='align_images_test')
+    cv2.destroyAllWindows()
     return
 
 
