@@ -35,12 +35,16 @@ def get_host_name() -> str:
 
 def get_active_ipv4() -> str:
     """
-     :return ipv4 address of this computer
-     see get_ipv4_test()
-     """
-    s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-    s.connect(("8.8.8.8", 80))
-    ipv4 = s.getsockname()[0]
+    :return ipv4 address of this computer
+    see get_ipv4_test()
+    """
+    try:
+        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
+        s.connect(("8.8.8.8", 80))
+        ipv4 = s.getsockname()[0]
+    except OSError as e:
+        mt.exception_error('No connection: {}'.format(e), real_exception=True)
+        ipv4 = 'N/A'
     return ipv4
 
 
@@ -255,7 +259,10 @@ def map_brute_force(start_idx: int = 0, end_idx: int = 254, ack: bool = True) ->
     --------------------------------------------------------------------------------
     Total run time 0:00:04
     """
+    ips_found = []
     my_ip = get_active_ipv4()
+    if my_ip == 'N/A':
+        return ips_found
     pref_ip = my_ip.split('.')[:3]  # take first 3 chars e.g. 192.168.0.8 -> 192.168.0
     pref_ip = '.'.join(pref_ip)
     pref_ip += '.{}'  # add variable format
@@ -263,7 +270,7 @@ def map_brute_force(start_idx: int = 0, end_idx: int = 254, ack: bool = True) ->
         print('local network prefix {}'.format(pref_ip))
         print('checking from {} where X goes from {} to {}...'.format(pref_ip.format('X'), start_idx, end_idx))
     pool = list()
-    ips_found = []
+
     for i in range(start_idx, end_idx):
         address = pref_ip.format(i)
         # check_ip(ip=address)
@@ -334,10 +341,13 @@ def map_devices_arp(known_devices: dict = None, ack: bool = True):
     --------------------------------------------------------------------------------
     Total run time 0:00:04
     """
+    ip_mac = {}
+    my_ip = get_active_ipv4()
+    if my_ip == 'N/A':
+        return ip_mac
     map_brute_force(ack=False)  # refresh arp cache table
     out_lines = mt.run_shell_command_and_get_out(cmd='arp -a', ack_cmd=True, ack_out=False)
 
-    ip_mac = {}
     for line in out_lines:
         if 'dynamic' in line:  # break down the output keep only dynamic addresses
             line = ' '.join(line.split())  # many spaces to 1
@@ -497,14 +507,15 @@ def get_active_con_mac(with_colons: bool = True, ack: bool = False) -> str:
     active_con = None
     mac12_con = None
     ipv4 = get_active_ipv4()
-    info_d = get_all_network_info(with_colons=with_colons, ack=False)
-    for interface, info in info_d.items():
-        if 'ip' in info and info['ip'] == ipv4:
-            if 'mac12' in info:
-                mac12_con = info['mac12']
-                active_con = interface
-    if ack:
-        print('\tactive con({}) mac {}'.format(active_con, mac12_con))
+    if not ipv4 == 'N/A':
+        info_d = get_all_network_info(with_colons=with_colons, ack=False)
+        for interface, info in info_d.items():
+            if 'ip' in info and info['ip'] == ipv4:
+                if 'mac12' in info:
+                    mac12_con = info['mac12']
+                    active_con = interface
+        if ack:
+            print('\tactive con({}) mac {}'.format(active_con, mac12_con))
     return mac12_con
 
 
