@@ -141,7 +141,7 @@ def get_host_name_test():
 
 def get_active_ipv4_test():
     mt.get_function_name(ack=True, tabs=0)
-    print('\t{}'.format(st.get_active_ipv4()))
+    print('\tactive_ipv4: {}'.format(st.get_active_ipv4()))
     return
 
 
@@ -156,13 +156,18 @@ def buffer_to_str_test():
 
 def download_file_test():
     mt.get_function_name(ack=True, tabs=0)
-    mt.create_dir(mtt.TEMP_FOLDER1)
+    dir_path = mtt.TEMP_FOLDER1
+    if not os.path.exists(dir_path):
+        mt.create_dir(dir_path)
     dst = '{}/{}.jpg'.format(mtt.TEMP_FOLDER1, mtt.SO_LOGO)
-    st.download_file(url=mtt.IMAGES_D[mtt.SO_LOGO], dst_path=dst)
-    print('\t{} exists ? {}'.format(dst, os.path.exists(dst)))
-
-    # st.download_file(url=mtt.IMAGES_D[mtt.SO_LOGO], dst_path=dst)  # check no overwrite - will fail
-    mt.delete_dir_with_files(dir_path=mtt.TEMP_FOLDER1)
+    url = mtt.IMAGES_D[mtt.SO_LOGO]
+    ret = st.download_file(url=url, dst_path=dst)
+    if not ret:
+        print('\tdownload of {} failed'.format(url))
+    else:
+        print('\t{} exists ? {}'.format(dst, os.path.exists(dst)))
+        # st.download_file(url=mtt.IMAGES_D[mtt.SO_LOGO], dst_path=dst)  # check no overwrite - will fail
+        mt.delete_dir_with_files(dir_path=mtt.TEMP_FOLDER1)
     return
 
 
@@ -178,8 +183,10 @@ def get_file_size_by_url_test():
     for url in urls:
         url_file = url.split('/')[-1]
         s = st.get_file_size_by_url(url=url)
-        print('\tfile {} size is {}'.format(url_file, s))
-
+        if s == 'N/A':
+            print('\tdownload of {} failed'.format(url_file))
+        else:
+            print('\tfile {} size is {}'.format(url_file, s))
     return
 
 
