@@ -1,6 +1,3 @@
-"""
-:requires: pyttsx3
-"""
 try:
     from wizzi_utils.tts.tts import *
 except ModuleNotFoundError as e:
